==> king-phisher_1.13.1.orig.tar.gz: king-phisher-1.13.1/tests/server/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  tests/server/__init__.py
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are
#  met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following disclaimer
#    in the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the project nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

import logging
logging.getLogger('KingPhisher').addHandler(logging.NullHandler)
logging.getLogger('').setLevel(logging.CRITICAL)

from .aaa import ServerAuthenticatedSessionManagerTests
from .aaa import ServerAuthenticationTests
from .aaa import ServerCachedPasswordTests
from .configuration import ServerConfigurationTests
from .database import *
from .graphql import ServerGraphQLTests
from .graphql import ServerGraphQLDatabaseTests
from .rest_api import ServerRESTAPITests
from .server import CampaignWorkflowTests
from .server import ServerTests
from .server_rpc import ServerRPCTests
from .template_extras import TemplateExtraTests
from .web_tools import ServerWebToolsTests

==> king-phisher_1.15.0.orig.tar.gz: king-phisher-1.15.0/tests/server/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  tests/server/__init__.py
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are
#  met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following disclaimer
#    in the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the project nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

import logging
logging.getLogger('KingPhisher').addHandler(logging.NullHandler())
logging.getLogger('').setLevel(logging.CRITICAL)

from .aaa import ServerAuthenticatedSessionManagerTests
from .aaa import ServerAuthenticationTests
from .aaa import ServerCachedPasswordTests
from .configuration import ServerConfigurationTests
from .database import *
from .graphql import ServerGraphQLTests
from .graphql import ServerGraphQLDatabaseTests
from .letsencrypt import ServerSNIHostnameTests
from .rest_api import ServerRESTAPITests
from .server import CampaignWorkflowTests
from .server import ServerTests
from .server_rpc import ServerRPCTests
from .template_extras import TemplateExtraTests
from .web_tools import ServerWebToolsTests
